Function for GaussSuppressionFromData
PrimaryDefault(freq, maxN = 3, protectZeros = TRUE, freqVar, ...)primary, GaussSuppression input
Vector of output frequencies
Cells with frequency <= maxN are set as primary suppressed.
Can also be a named list or vector, where the value corresponding to freqVar will be used
if available. If not found, the name "freq" is tried as an alternative.
When TRUE, cells with zero frequency are set as primary suppressed.
Character string used to select the appropriate value from maxN if it is a named object.
see maxN above.
Unused parameters